#include <bits/stdc++.h>

const int N = 1100;

using ll = long long;

class point {
public:
	int x, y;

	point() = default;

	point(int _x, int _y) : x(_x), y(_y) {}

	point operator+(const point& other) const {
		return point(x + other.x, y + other.y);
	}

	point operator-(const point& other) const {
		return point(x - other.x, y - other.y);
	}

	ll operator*(const point& other) const {
		return 1ll * x * other.x + 1ll * y * other.y;
	}

	ll operator%(const point& other) const {
		return 1ll * x * other.y - 1ll * y * other.x;
	}

	void scan() {
		scanf("%d%d", &x, &y);
	}

	int quad() const {
		if (x >= 0 && y > 0) {
			return 1;
		} else if (x < 0 && y >= 0) {
			return 2;
		} else if (x <= 0 && y < 0) {
			return 3;
		} else if (x > 0 && y <= 0) {
			return 4;
		} else {
			assert(false);
		}
	}

	ll lenSqr() const {
		return 1ll * x * x + 1ll * y * y;
	}

	bool operator==(const point& other) const {
		return x == other.x && y == other.y;
	}
};

point a[N][2];

bool inSegment(const point& p, const point& p1, const point& p2) {
	if ((p - p1) % (p2 - p1) != 0) {
		return false;
	}
	if ((p - p1) * (p2 - p1) <= 0) {
		return false;
	}
	if ((p - p2) * (p1 - p2) <= 0) {
		return false;
	}
	return true;
}

point getVector(const point& center, int segId) {
	if (center == a[segId][0]) {
		return a[segId][1] - a[segId][0];
	} else {
		return a[segId][0] - a[segId][1];
	}
}

void solve() {
	int n;
	scanf("%d", &n);

	std::vector<point> allPoints;
	for (int i = 0; i < n; ++i) {
		a[i][0].scan();
		a[i][1].scan();
		allPoints.push_back(a[i][0]);
		allPoints.push_back(a[i][1]);
	}

	auto cmp = [&](const point& p1, const point& p2) {
		return p1.x < p2.x || (p1.x == p2.x && p1.y < p2.y);
	};
	std::sort(allPoints.begin(), allPoints.end(), cmp);
	allPoints.resize(std::unique(allPoints.begin(), allPoints.end()) - allPoints.begin());
	
	std::vector<std::vector<int>> segmentsByPoint(allPoints.size());
	for (int i = 0; i < n; ++i) {
		int id1 = std::lower_bound(allPoints.begin(), allPoints.end(), a[i][0], cmp) - allPoints.begin();
		int id2 = std::lower_bound(allPoints.begin(), allPoints.end(), a[i][1], cmp) - allPoints.begin();
		segmentsByPoint[id1].push_back(i);
		segmentsByPoint[id2].push_back(i);
	}

	for (int i = 0; i < (int)allPoints.size(); ++i) {
		std::sort(segmentsByPoint[i].begin(), segmentsByPoint[i].end(), [&](int s1, int s2) {
			point p = allPoints[i];
			point p1 = (a[s1][0] == p ? a[s1][1] : a[s1][0]);
			point p2 = (a[s2][0] == p ? a[s2][1] : a[s2][0]);

			point v1 = p1 - p;
			point v2 = p2 - p;

			if (v1.quad() != v2.quad()) {
				return v1.quad() < v2.quad();
			} else {
				ll cross = v1 % v2;
				if (cross != 0) {
					return cross > 0;
				} else {
					return v1.lenSqr() < v2.lenSqr();
				}
			}
		});
	}

	ll ans = 0;
	for (int segId = 0; segId < n; ++segId) {
		for (int pointId = 0; pointId < (int)allPoints.size(); ++pointId) {
			auto point = allPoints[pointId];
			if (!inSegment(point, a[segId][0], a[segId][1])) {
				continue;
			}

			int cnt1 = 0, cnt2 = 0;
			int equalCnt = 1;
			for (int i = 0; i < (int)segmentsByPoint[pointId].size(); ++i) {
				int otherSegmentId = segmentsByPoint[pointId][i];
				ll cross = getVector(point, otherSegmentId) % (a[segId][1] - a[segId][0]);
				if (cross == 0) {
					ans -= 1ll * equalCnt * (equalCnt - 1) / 2;
					equalCnt = 1;
					continue;
				}	

				if (cross > 0) {
					++cnt1;
				} else {
					++cnt2;
				}


				if (i != 0 && getVector(point, otherSegmentId) % getVector(point, segmentsByPoint[pointId][i - 1]) == 0 && getVector(point, otherSegmentId) * getVector(point, segmentsByPoint[pointId][i - 1]) > 0) {
					++equalCnt;
				} else {
					ans -= 1ll * equalCnt * (equalCnt - 1) / 2;
					equalCnt = 1;
				}
			}
			ans -= 1ll * equalCnt * (equalCnt - 1) / 2;

			ans += 1ll * cnt1 * (cnt1 - 1) / 2;
			ans += 1ll * cnt2 * (cnt2 - 1) / 2;
		}
	}

	printf("%lld\n", ans);
}

int main() {
	int t;
	scanf("%d", &t);

	while (t--) {
		solve();
	}

	return 0;
}