#include<bits/stdc++.h>

using namespace std;

#define cerr if(0)cerr

typedef long long ll;

const int C = 1e6 + 5;

struct Point {
    int x, y;

    Point() {}

    Point(int x, int y): x(x), y(y) {}

    friend bool operator < (Point &A, Point &B) {
        return make_pair(A.x, A.y) < make_pair(B.x, B.y);
    }

    friend bool operator > (Point &A, Point &B) {
        return make_pair(A.x, A.y) > make_pair(B.x, B.y);
    }

    friend bool operator == (Point &A, Point &B) {
        return make_pair(A.x, A.y) == make_pair(B.x, B.y);
    }

    ll getHash() {
        return 1ll * (x + C) * (2 * C) + 1ll * (y + C);
    }
};

struct Segment {
    Point A, B;

    Segment() {}

    Segment(Point A, Point B): A(A), B(B) {}

    friend bool operator == (Segment &a, Segment &b) {
        return a.A == b.A  && a.B == b.B || a.A == b.B && a.B == b.A;
    }
};

struct Vector {
    int x, y;

    Vector() {}

    Vector(int x, int y): x(x), y(y) {}

    Vector(Point A, Point B): x(B.x - A.x), y(B.y - A.y) {}

    friend ll operator % (Vector v, Vector u) {
        return 1ll * v.x * u.y - 1ll * v.y * u.x;
    }
};

const int N = 1005;

int n;
Segment a[N];
Vector va[N];
ll cp[N][N];

bool areCollinear(Vector v, Vector u) {
    return v % u == 0;
}

ll squaredDist(Point A, Point B) {
    return 1ll * (A.x - B.x) * (A.x - B.x) + 1ll * (A.y - B.y) * (A.y - B.y);
}

bool strictryInsideSegment(Point M, Segment s) {
    return !(s.A == M) && !(s.B == M) && areCollinear(Vector(s.A, M), Vector(s.A, s.B)) &&
        squaredDist(s.A, M) < squaredDist(s.A, s.B);
}

int getSide(Point M, Segment s) {
    return Vector(s.A, s.B) % Vector(s.A, M) > 0;
}

bool cmp(pair<ll, int> &x, pair<ll, int> &y) {
    if (x.first != y.first) return x.first < y.first;
    int i = x.second, j = y.second;
    return cp[i][j] > 0;
}

ll solve(vector<int> &c) {
    int i = 0, k = (int) c.size();
    ll ans = 1ll * k * (k - 1) / 2;
    while (i < k) {
        int j = i;
        while (j < k && cp[c[i]][c[j]] == 0) {
            ++j;
        }
        int m = j - i;
        ans -= 1ll * m * (m - 1) / 2;
        i = j;
    }
    return ans;
}

ll solve(vector<pair<ll, int>> &b) {
    ll ans = 0;
    int i = 0, k = (int) b.size();
    while (i < k) {
        int j = i;
        vector<int> c;
        while (j < k && b[i].first == b[j].first) {
            c.emplace_back(b[j].second);
            ++j;
        }
        i = j;
        ans += solve(c);
    }
    return ans;
}

void solve() {
    cin >> n;
    for (int i = 1; i <= n; ++i) {
        int w, x, y, z;
        cin >> w >> x >> y >> z;
        a[i] = Segment(Point(w, x), Point(y, z));
        if (a[i].A > a[i].B) swap(a[i].A, a[i].B);
        va[i] = Vector(a[i].A, a[i].B);
    }
    for (int i =1; i <= n; ++i) {
        for (int j = 1; j <= n; ++j) {
            cp[i][j] = va[i] % va[j];
        }
    }
    ll ans = 0;
    for (int i = 1; i <= n; ++i) {
        vector<pair<ll, int>> side1, side2;
        for (int j = 1; j <= n; ++j) {
            if (a[i] == a[j]) continue;
            if (areCollinear(va[i], va[j])) continue;
            bool x = strictryInsideSegment(a[j].A, a[i]), y = strictryInsideSegment(a[j].B, a[i]);
            if (x && y) continue;
            if (!x && !y) continue;
            if (x) {
                if (getSide(a[j].B, a[i]) == 1) side1.emplace_back(a[j].A.getHash(), j);
                else side2.emplace_back(a[j].A.getHash(), j);
            } else {
                if (getSide(a[j].A, a[i]) == 1) side1.emplace_back(a[j].B.getHash(), j);
                else side2.emplace_back(a[j].B.getHash(), j);
            }
        }
        sort(side1.begin(), side1.end(), cmp);
        sort(side2.begin(), side2.end(), cmp);
        ans += solve(side1);
        ans += solve(side2);
    }
    cout << ans << "\n";
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    int t;
    cin >> t;
    while(t--) {
        solve();
    }
}

