#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <algorithm>

#define all(a) a.begin(), a.end()
#define rsort(a) sort(a, [&](auto c, auto b){return c > b;})

using namespace std;

using ll = long long;

ll inf = 1e18;

struct SegmentTree
{
	struct Node
	{
		ll val;
		ll cnt;

		Node(ll Val = inf, ll Cnt = 1) : val(Val), cnt(Cnt) {}
	};

	Node neutral = Node();

	ll n;
	vector<Node> tree;

	Node merge(Node n1, Node n2)
	{
		if (n1.val < n2.val)
		{
			return n1;
		}
		else if (n1.val > n2.val)
		{
			return n2;
		}
		else
		{
			return Node(n1.val, n1.cnt + n2.cnt);
		}
	}

	void fix(ll v)
	{
		tree[v] = merge(tree[v * 2 + 1], tree[v * 2 + 2]);
	}

	SegmentTree(ll N = 0)
	{
		n = N;
		tree.assign(4 * n + 1, 0);
		vector<ll> start(n, 0);

		init(0, 0, n, start);
	}

	SegmentTree(vector<ll>& start)
	{
		n = start.size();
		tree.assign(4 * n + 1, neutral);

		init(0, 0, n, start);
	}

	void init(ll v, ll l, ll r, vector<ll>& start)
	{
		if (l + 1 == r)
		{
			tree[v] = Node(start[l]);
			return;
		}

		ll m = (r + l) / 2;
		init(v * 2 + 1, l, m, start);
		init(v * 2 + 2, m, r, start);
		fix(v);
	}

	Node query(ll v, ll l, ll r, ll ql, ll qr)
	{
		if (r <= ql || qr <= l)
		{
			return neutral;
		}
		if (ql <= l && r <= qr)
		{
			return tree[v];
		}

		ll m = (r + l) / 2;
		return merge(
			query(v * 2 + 1, l, m, ql, qr),
			query(v * 2 + 2, m, r, ql, qr)
		);
	}

	Node query(ll ql, ll qr)
	{
		return query(0, 0, n, ql, qr);
	}

	void change(ll v, ll l, ll r, ll id, ll val)
	{
		if (r <= id || l > id)
		{
			return;
		}
		if (l == id && r == id + 1)
		{
			tree[v] = Node(val);
			return;
		}

		ll m = (r + l) / 2;
		change(v * 2 + 1, l, m, id, val);
		change(v * 2 + 2, m, r, id, val);
		fix(v);
	}

	void change(ll id, ll val)
	{
		change(0, 0, n, id, val);
	}

	void add(ll v, ll l, ll r, ll id, ll val)
	{
		if (r <= id || l > id)
		{
			return;
		}
		if (l == id && r == id + 1)
		{
			tree[v] = Node(tree[v].val + val);
			return;
		}

		ll m = (r + l) / 2;
		add(v * 2 + 1, l, m, id, val);
		add(v * 2 + 2, m, r, id, val);
		fix(v);
	}

	void add(ll id, ll val)
	{
		add(0, 0, n, id, val);
	}

};


struct SegmentTreeMass
{
	struct Node
	{
		ll val;
		ll add;

		Node(ll Val = 0, ll Add = 0) : val(Val), add(Add) {}
	};

	Node neutral = Node();

	ll n;
	vector<Node> tree;

	Node merge(Node n1, Node n2)
	{
		return Node(n1.val + n2.val);
	}

	void fix(ll v, ll l, ll r)
	{
		push(v, l, r);
		tree[v] = merge(tree[v * 2 + 1], tree[v * 2 + 2]);
	}

	void push(ll v, ll l, ll r)
	{
		ll m = (r + l) / 2;
		tree[2 * v + 1].add += tree[v].add;
		tree[2 * v + 1].val += (m - l) * tree[v].add;
		tree[2 * v + 2].add += tree[v].add;
		tree[2 * v + 2].val += (r - m) * tree[v].add;
		tree[v].add = 0;
	}

	SegmentTreeMass(ll N = 0)
	{
		n = N;
		tree.assign(4 * n + 1, 0);
		vector<ll> start(n, 0);
		init(0, 0, n, start);
	}

	SegmentTreeMass(vector<ll>& start)
	{
		n = start.size();
		tree.assign(4 * n + 1, neutral);
		init(0, 0, n, start);
	}

	void init(ll v, ll l, ll r, vector<ll>& start)
	{
		if (l + 1 == r)
		{
			tree[v] = Node(start[l]);
			return;
		}

		push(v, l, r);
		ll m = (r + l) / 2;
		init(v * 2 + 1, l, m, start);
		init(v * 2 + 2, m, r, start);
		fix(v, l, r);
	}

	Node query(ll v, ll l, ll r, ll ql, ll qr)
	{
		if (r <= ql || qr <= l)
		{
			return neutral;
		}
		if (ql <= l && r <= qr)
		{
			return tree[v];
		}

		push(v, l, r);
		ll m = (r + l) / 2;
		return merge(
			query(v * 2 + 1, l, m, ql, qr),
			query(v * 2 + 2, m, r, ql, qr)
		);
	}

	Node query(ll ql, ll qr)
	{
		return query(0, 0, n, ql, qr);
	}

	void add(ll v, ll l, ll r, ll ql, ll qr, ll val)
	{
		if (r <= ql || qr <= l)
		{
			return;
		}
		if (ql <= l && r <= qr)
		{
			tree[v].val += val*(r - l);
			tree[v].add += val;
			return;
		}

		push(v, l, r);
		ll m = (r + l) / 2;
		add(v * 2 + 1, l, m, ql, qr, val);
		add(v * 2 + 2, m, r, ql, qr, val);
		fix(v, l, r);
	}

	void add(ll ql, ll qr, ll val)
	{
		add(0, 0, n, ql, qr, val);
	}

};


int main()
{
	ll n; cin >> n;
	vector<ll> a(n);
	for (int i = 0; i < n; ++i)
		cin >> a[i];

	SegmentTree st(a);
	vector<ll> am(n);
	am[0] = a[0];

	for (int i = 1; i < n; ++i)
	{
		am[i] = min(a[i], am[i - 1]);
	}

	SegmentTreeMass stm(am);

	cout << stm.query(0, n).val << '\n';

	ll q; cin >> q;
	while (q--)
	{
		ll T, k; cin >> T >> k;

		ll l = k, r = n;
		ll ak = st.query(k, k + 1).val;
		ll amk = stm.query(k, k + 1).val;

		ll c = stm.query(k, n).val;

		ll t = k;

		if (c == ak * (n - k))
			t = n - 1;
		else
		{
			while (r - l > 1)
			{
				ll m = (r + l) / 2;
				c = stm.query(k, m + 1).val;
				if (c == ak * (m + 1 - k))
					l = m;
				else
					r = m;

			}
			t = l;
		}


		if (T == 1)
		{
			// ++a[k]

			if (ak == amk)
			{
				ll cnt = st.query(0, k + 1).cnt;
				if (cnt == 1)
				{
					cnt = st.query(0, t + 1).cnt;
					if (cnt == 1)
					{
						stm.add(k, t + 1, 1);
					}
					else
					{
						ll l = k, r = t;

						while (r - l > 0)
						{
							ll m = (r + l) / 2;
							cnt = st.query(0, m + 1).cnt;
							if (cnt == 1)
								l = m;
							else
								r = m;
						}

						t = l;

						stm.add(k, t + 1, 1);
					}
				}
			}

			st.add(k, 1);
		}
		else
		{
			// --a[k]

			if (ak == amk)
			{
				stm.add(k, t + 1, -1);
			}

			st.add(k, -1);
		}


		cout << stm.query(0, n).val << '\n';
	}

	return 0;
}